import java.util.Scanner;
import java.util.Arrays;

public class CharSequence {

        /**
        * main-Methode: liest von der Standardeingabe ein und arbeitet die
        * einegegebenen Befehle ab. Erzeugt entsprechende Ausgaben.
        */
        public static void main(String[] args) {

                Scanner sc = new Scanner(System.in);

                String eingabe = sc.nextLine();

                //macht aus einem String ein char-Array
                char[] charSeq = eingabe.toCharArray();

                while (sc.hasNext()) {

                        String command = sc.next();

                        if (command.equals("print")) {
                                System.out.println(Arrays.toString(charSeq));
                        } else if (command.equals("repeat")) {
                                char c = sc.next().charAt(0);
                                int length = sc.nextInt();
                                charSeq = repeat(c, length);
                        } else if(command.equals("replace")) {
                                int i = sc.nextInt();
                                int j = sc.nextInt();
                                String s = sc.next();
                                charSeq = replace(charSeq, i, j,
                                        s.toCharArray());
                        } else if(command.equals("decode")) {
                                charSeq = decode(charSeq);
                        }
                }
        }

        /**
        * Erzeugt ein neues Array durch Hintereinanderreihen des angegebenen
        * Zeichens. Das Array soll die angegebene Länge haben.
        *
        * @param ch Das Zeichen, aus dem die Zeichenfolge besteht
        * @param length Die Länge der Zeichenfolge
        * @return Die Zeichefolge bestehend aus gleichen Zeichen ch
        */
        public static char[] repeat(char ch, int length) {
                char[] array = new char[length];

                for (int i = 0; i < length; i++) {
                    array[i] = ch;
                }

                return array;
        }

        /**
        * In der spezifizierten Zeichenfolge des Array arr wird ein bestimmter
        * Bereich durch die Zeichenfolge des Arrays from ersetzt. Der Bereich im
        * arr umfasst die Zeichen mit den Indizes beginIndex(inklusive) bis
        * endIndex (exklusive, d.h. die Position endIndex ist nicht mehr
        * inkludiert).
        *
        * Die Größe des Quellarrays ist im Allgemeinen nicht gleich der
        * Größe des zu ersetzenden Bereichs, weshalb die Größe des
        * Ergebnissarrays von der Größe von arr abweichen kann. Die Methode soll
        * keine Veränderung in arr selbst bewirken.
        *
        * Der Fall arr oder from gleich null muss nicht beachtet werden.
        *
        * ACHTUNG: Die Methode soll ohne Aufruf von Methoden aus
        * java.util.Arrays
        * oder Systems.arraycopy und ohne Verwendung der Datentypen String,
        * StringBuilder oder StringBuffer programmiert werden.
        *
        * @param arr Das Array in dem die Zeichen ersetzt werden
        * @param beginIndex Der Startposition des zu ersetzenden Bereichs.
        * @param endIndex Die Position des ersten Zeichens nach dem zu
        * ersetzenden Bereich. Dieses Zeichen wird nicht mehr ersetzt.
        * @param from Das Array, dessen Inhalt den spezifizierten Bereich
        * ersetzen soll. Die Größe dieses Arrays ist im Allgemeinen nicht gleich
        * der Größe des zu ersetzenden Bereichs, weshalb die Größe des
        * Ergebnisses dieser Operation von ursprünglichen Größe von arr
        * abweichen kann.
        */
        public static char[] replace(char[] arr, int beginIndex, int endIndex, char[] from) {
                char[] newArr = new char[arr.length - (endIndex - beginIndex) +
                    from.length];
                int i = 0, j = 0;

                for (i = 0, j = 0; i < beginIndex; i++, j++) {
                    newArr[j] = arr[i];
                }

                for (i = 0; i < from.length; i++, j++) {
                    newArr[j] = from[i];
                }

                for (i = endIndex; i < arr.length; i++, j++) {
                    newArr[j] = arr[i];
                }

                return newArr;
        }

        /**
        * Dekodiert die Zeichenfolge gemäß der Angabe. Die kodierte Zeichenfolge
        * enthält abwechselnd eine Ziffer gefolgt von einem Zeichen (beginnend
        * mit einer Ziffer). Die Ziffer gibt jeweils die Anzahl der
        * Wiederholungen des daraufolgenden Zeichens in der dekodierten
        * Zeichenfolge an.
        *
        * ACHTUNG: Die Methode soll ohne Aufruf von Methoden aus
        * java.util.Arrays oder Systems.arraycopy und ohne Verwendung der
        * Datentypen String, StringBuilder oder StringBuffer programmiert
        * werden.
        *
        * @param arr Das Original-Array mit der kodierten Zeichenfolge
        * @return Ein Array das die dekodierte Form der Zeichenfolge enthält
        */
        public static char[] decode(char[] arr) {
                char[] newArr = new char[arr.length];
                int i = 0, length = 0;

                // create a deep copy
                for (i = 0; i < arr.length; i++) {
                    newArr[i] = arr[i];
                }

                for (i = 0; i < newArr.length; i += length) {
                    length = char2int(newArr[i]);
                    newArr = replace(newArr, i, i + 2, repeat(newArr[i + 1],
                                length));
                }

                return newArr;
        }

        /**
        * Diese vorgegebene Hilfsmethode wandelt ein Ziffernzeichen in den
        * entsprechenden int-Wert um.
        * Vorbedingung: ch ist eine Ziffer ('0'-'9')
        *
        * @param ch Die Ziffer als char
        * @return Die Ziffer als int
        */
        public static int char2int(char ch) {
                return ch - '0';
        }

}
